#!/usr/bin/perl -w

use strict;

if ( $#ARGV < 1 ) {
  print "Usage: <simplefile> <detailedfile>\n";
  exit 1;
}

my $simplefile = $ARGV[0];
my $detailedfile = $ARGV[1];


my $jsontext = join("\n", <STDIN>);

use lib qw/src/;
use GPS::Garmin::Connect;

my $gc = GPS::Garmin::Connect->new();

my $simpleactivities = $gc->parse($jsontext);



### Now print the "simple" sidebar
my $i = 0;
print "Writing $simplefile ...\n";
open(SIMPLE, ">$simplefile");
print SIMPLE '<table class="simpleruns"><tr><th><a style="text-decoration:none;" href="http://herbert.poul.at/wiki/show/Running/">My last 3 runs</a>:</th></tr>';
foreach my $ac (@$simpleactivities) {
  # ignore everything without any heartrate.
  next unless defined $ac->{heartrate};
  # ignore anything with the activity name 'IGNORE'
  next if $ac->{activity} =~ /IGNORE/;
  last if $i++ > 2;
  my $label = $ac->{activity};
  $label = $ac->{type} if $label eq 'Untitled';
  print SIMPLE qq~
<tr>
  <th class="simplerun"><a href="http://connect.garmin.com/activity/$ac->{id}" target="_blank">$label</a></th>
</tr>
<tr><td>$ac->{begindate}</td></tr>
<tr><td>$ac->{distance} km @ $ac->{heartrate} bpm</td></tr>
~;
}
print SIMPLE '<tr><td><a href="http://herbert.poul.at/wiki/show/Running/">All my runs</a></td></tr>';
print SIMPLE "</table>";

close(SIMPLE);


print "Writing $detailedfile ...\n";
open(DETAILED, ">$detailedfile");

print DETAILED qq~<table class="detailedruns"><tr><th colspan="5">My latest runs</th></tr>
<tr>
  <th>Name</th>
  <th>Date</th>
  <th>Duration</th>
  <th>Distance</th>
  <th>Heartrate</th>
</tr>
~;
foreach my $ac (@$simpleactivities) {
  # ignore everything without any heartrate.
  next unless defined $ac->{heartrate};
  # ignore anything with the activity name 'IGNORE'
  next if $ac->{activity} =~ /IGNORE/;
  
  print DETAILED qq~
<tr>
  <td><a href="http://connect.garmin.com/activity/$ac->{id}" target="_blank">$ac->{activity}</a> <small>($ac->{type})</small></td>
  <td class="date">$ac->{begindate}</td>
  <td class="duration">$ac->{duration}</td>
  <td class="distance">$ac->{distance} km</td>
  <td class="heartrate">$ac->{heartrate} bpm</td>
</tr>~;
}
print DETAILED '</table>';
close(DETAILED);



